@@ -5,12 +5,12 @@ use warnings;
 use Carp qw( croak );
 use FFI::Platypus;
 use base qw( Exporter );
-use constant 1.32 ();
+use constant ();
 
 our @EXPORT = qw( record_layout );
 
 # ABSTRACT: FFI support for structured records data
-our $VERSION = '0.36'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 
 sub record_layout
@@ -79,8 +79,18 @@ sub record_layout
   my $size = $offset;
   
   no strict 'refs';
-  constant->import(join('::', $caller, '_ffi_record_size'), $size);
-  constant->import(join('::', $caller, '_ffi_record_align'), $record_align);
+  # Required version of constant is not on 
+  # CPAN yet.  Nice.
+  if($constant::VERSION > 1.32)
+  {
+    constant->import(join('::', $caller, '_ffi_record_size'), $size);
+    constant->import(join('::', $caller, '_ffi_record_align'), $record_align);
+  }
+  else
+  {
+    *{join '::', $caller, '_ffi_record_size'}  = sub () { $size         };
+    *{join '::', $caller, '_ffi_record_align'} = sub () { $record_align };
+  }
   *{join '::', $caller, 'new'} = sub {
     my $class = shift;
     my $args = ref($_[0]) ? [%{$_[0]}] : \@_;
@@ -128,7 +138,7 @@ FFI::Platypus::Record - FFI support for structured records data
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
